package cn.com.ctop.kuaishou.modules.ai.service.impl;

import cn.com.ctop.common.module.utils.Check;
import cn.com.ctop.kuaishou.modules.ai.entity.AiKuaiShouAppInfo;
import cn.com.ctop.kuaishou.modules.ai.mapper.AiKuaiShouAppInfoMapper;
import cn.com.ctop.kuaishou.modules.ai.service.IAiKuaiShouAppInfoService;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFDateUtil;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * ai批量上传应用
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2021-02-02
 */
@Service
public class AiKuaiShouAppInfoServiceImpl extends ServiceImpl<AiKuaiShouAppInfoMapper, AiKuaiShouAppInfo> implements IAiKuaiShouAppInfoService {

    /**
     * 文件导入
     *
     * @param
     * @param accountId
     * @param imageToken
     * @return
     */
    @Override
    public JSONObject importExcel(MultipartFile myFile, Long accountId, String imageToken) {
        try {
            Workbook workbook = null;
            String fileName = myFile.getOriginalFilename();
            if (fileName.endsWith("XLS")) {
                //2003
                workbook = new HSSFWorkbook(myFile.getInputStream());
            } else if (fileName.endsWith("XLSX")) {
                //2007
                workbook = new XSSFWorkbook(myFile.getInputStream());
            } else {
                //   throw new Exception("文件不是Excel文件");
            }

            Sheet sheet = workbook.getSheet("Sheet1");
            int rows = sheet.getLastRowNum();// 指的行数，一共有多少行+
            if (rows == 0) {
                // throw new Exception("请填写数据");
            }
            for (int i = 1; i <= rows + 1; i++) {
                // 读取左上端单元格
                Row row = sheet.getRow(i);
                // 行不为空
                if (row != null) {
                    // **读取cell**
                    AiKuaiShouAppInfo appInfo = new AiKuaiShouAppInfo();

                    String appName = getCellValue(row.getCell(0));
                    appInfo.setAppName(appName);

                    String packageName = getCellValue(row.getCell(1));
                    appInfo.setPackageName(packageName);

                    String appVersion = getCellValue(row.getCell(2));
                    appInfo.setAppVersion(appVersion);

                    String useSdk = getCellValue(row.getCell(3));
                    if (!Check.isNull(useSdk)) {
                        appInfo.setUseSdk(Integer.valueOf(useSdk));
                    }
                    String appPrivacyUrl = getCellValue(row.getCell(4));
                    if (!Check.isNull(appPrivacyUrl)) {
                        appInfo.setAppPrivacyUrl(appPrivacyUrl);
                    }

                    String trackUrl = getCellValue(row.getCell(5));
                    if (!Check.isNull(trackUrl)) {
                        appInfo.setTrackUrl(trackUrl);
                    }
                    //考试时间
                  /*  SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");//小写的mm表示的是分钟
                    String dateString = getCellValue(row.getCell(3));
                    if (!StringUtils.isEmpty(dateString)) {
                        Date date = sdf.parse(dateString);
                        student.setTime(date);
                    }
                    studentMapper.insert(student);*/
                }
            }

        } catch (Exception e) {
            e.printStackTrace();

        }
        return null;
    }


    private String getCellValue(Cell cell) {
        String value = "";
        if (cell != null) {
            // 以下是判断数据的类型
            switch (cell.getCellType()) {
                case HSSFCell.CELL_TYPE_NUMERIC: // 数字
                    value = cell.getNumericCellValue() + "";
                    if (HSSFDateUtil.isCellDateFormatted(cell)) {
                        Date date = cell.getDateCellValue();
                        if (date != null) {
                            value = new SimpleDateFormat("yyyy-MM-dd").format(date);
                        } else {
                            value = "";
                        }
                    } else {
                        value = new DecimalFormat("0").format(cell.getNumericCellValue());
                    }
                    break;
                case HSSFCell.CELL_TYPE_STRING: // 字符串
                    value = cell.getStringCellValue();
                    break;
                case HSSFCell.CELL_TYPE_BOOLEAN: // Boolean
                    value = cell.getBooleanCellValue() + "";
                    break;
                case HSSFCell.CELL_TYPE_FORMULA: // 公式
                    value = cell.getCellFormula() + "";
                    break;
                case HSSFCell.CELL_TYPE_BLANK: // 空值
                    value = "";
                    break;
                case HSSFCell.CELL_TYPE_ERROR: // 故障
                    value = "非法字符";
                    break;
                default:
                    value = "未知类型";
                    break;
            }
        }
        return value.trim();
    }
}
